@@ -6,7 +6,7 @@ use warnings 'all';
 use Digest::MD5 'md5_hex';
 use Carp 'confess';
 
-our $VERSION = '0.000_03';
+our $VERSION = '0.000_04';
 
 sub import {
   my $class = shift;
@@ -29,7 +29,7 @@ sub _compile_code {
   my $sig = md5_hex($s->{code});
   my $cs = "/tmp/$s->{method}_$sig.cs";
   $s->{exe} = "/tmp/$s->{method}_$sig.exe";
-  my $compiler =  `which smcs`;
+  my $compiler =  `which gmcs`;
   chomp($compiler);
   my $cmd_line = "$compiler -out:$s->{exe} $s->{compiler_args} $cs";
   
